Test coverage - 100% score.c
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index 1bee09b136629594549c8f1c4c26604e3ab69b1a..cd4b9e6d2ff779ce65ca37decc1667165adc9723 100644 (file)
--- a/score.c
+++ b/score.c
@@ -50,14 +50,14 @@ long score(enum termination mode)
         }
     }
 
/*  Now look at how he finished and how far he got.  MAXDIE and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still
      *  indicates whether he reached the endgame.  And if he got as far as
      *  "cave closed" (indicated by "game.closed"), then bonus is zero for
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
-    score += (MAXDIE - game.numdie) * 10;
-    mxscor += MAXDIE * 10;
+    score += (maximum_deaths - game.numdie) * 10;
+    mxscor += maximum_deaths * 10;
     if (mode == endgame)
         score += 4;
     mxscor += 4;
@@ -87,9 +87,9 @@ long score(enum termination mode)
     mxscor += 2;
 
     /* Deduct for hints/turns/saves. Hints < 4 are special; see database desc. */
-    for (long i = 1; i <= HNTMAX; i++) {
+    for (long i = 0; i < HINT_COUNT; i++) {
         if (game.hinted[i])
-            score = score - HINTS[i][2];
+            score = score - hints[i].penalty;
     }
     if (game.novice)
         score -= 5;
@@ -99,9 +99,7 @@ long score(enum termination mode)
 
     /* Return to score command if that's where we came from. */
     if (mode == scoregame) {
-        SETPRM(1, score, mxscor);
-        SETPRM(3, game.turns, game.turns);
-        RSPEAK(GARNERED_POINTS);
+        rspeak(GARNERED_POINTS, score, mxscor, game.turns, game.turns);
     }
 
     return score;
@@ -113,23 +111,20 @@ void terminate(enum termination mode)
     long points = score(mode);
 
     if (points + game.trnluz + 1 >= mxscor && game.trnluz != 0)
-        RSPEAK(TOOK_LONG);
+        rspeak(TOOK_LONG);
     if (points + game.saved + 1 >= mxscor && game.saved != 0)
-        RSPEAK(WITHOUT_SUSPENDS);
-    SETPRM(1, points, mxscor);
-    SETPRM(3, game.turns, game.turns);
-    RSPEAK(TOTAL_SCORE);
+        rspeak(WITHOUT_SUSPENDS);
+    rspeak(TOTAL_SCORE, points, mxscor, game.turns, game.turns);
     for (long i = 1; i <= (long)CLSSES; i++) {
-        if (CVAL[i] >= points) {
-            speak(class_messages[i]);
-            i = CVAL[i] + 1 - points;
-            SETPRM(1, i, i);
-            RSPEAK(NEXT_HIGHER);
+        if (classes[i].threshold >= points) {
+            speak(classes[i].message);
+            i = classes[i].threshold + 1 - points;
+            rspeak(NEXT_HIGHER, i, i);
             exit(0);
         }
     }
-    RSPEAK(OFF_SCALE);
-    RSPEAK(NO_HIGHER);
+    rspeak(OFF_SCALE);
+    rspeak(NO_HIGHER);
     exit(0);
 }
@@ -50,14 +50,14 @@ long score(enum termination mode)
     }
 
-    /*  Now look at how he finished and how far he got.  MAXDIE and
+    /*  Now look at how he finished and how far he got.  maximum_deaths and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still